@@ -1,6 +1,6 @@
 /*
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2000, 2002, 2013, 2014, 2018  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 2000, 2002, 2013, 2014, 2018, 2019  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
 
@@ -411,14 +411,14 @@ namespace GNU_gama { namespace local {
           {
             LocalCoordinateSystem::CS& lcs = SB.local_coordinate_system;
 
-            if      (val == "ne") lcs = LocalCoordinateSystem::NE;
-            else if (val == "sw") lcs = LocalCoordinateSystem::SW;
-            else if (val == "es") lcs = LocalCoordinateSystem::ES;
-            else if (val == "wn") lcs = LocalCoordinateSystem::WN;
-            else if (val == "en") lcs = LocalCoordinateSystem::EN;
-            else if (val == "nw") lcs = LocalCoordinateSystem::NW;
-            else if (val == "se") lcs = LocalCoordinateSystem::SE;
-            else if (val == "ws") lcs = LocalCoordinateSystem::WS;
+            if      (val == "ne") lcs = LocalCoordinateSystem::CS::NE;
+            else if (val == "sw") lcs = LocalCoordinateSystem::CS::SW;
+            else if (val == "es") lcs = LocalCoordinateSystem::CS::ES;
+            else if (val == "wn") lcs = LocalCoordinateSystem::CS::WN;
+            else if (val == "en") lcs = LocalCoordinateSystem::CS::EN;
+            else if (val == "nw") lcs = LocalCoordinateSystem::CS::NW;
+            else if (val == "se") lcs = LocalCoordinateSystem::CS::SE;
+            else if (val == "ws") lcs = LocalCoordinateSystem::CS::WS;
             else
               return error(T_GKF_undefined_value_of_attribute
                            + nam + " = " + val);
