@@ -22,7 +22,7 @@
 #include <gnu_gama/xml/gkfparser.h>
 #include <gnu_gama/local/network.h>
 #include <gnu_gama/local/language.h>
-#include <gnu_gama/local/acord.h>
+#include <gnu_gama/local/acord/acord.h>
 #include <gnu_gama/local/test_linearization_visitor.h>
 
 double xyzMaxDiff(GNU_gama::local::LocalNetwork* lnet1,
