@@ -1,5 +1,5 @@
 /* matvec_test_002.cpp
-   Copyright (C) 2000, 2012  Ales Cepek <cepek@gnu.org>
+   Copyright (C) 2000, 2012, 2019  Ales Cepek <cepek@gnu.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,17 +27,17 @@ InitMat(Mat& M, double ini[], Mat& I, double inv[], double& cond, double& maxe)
 {
   long double inv0 = 1.0L/ini[0];
   inv[0] = inv0;
-  for (int i=1; i<M.rows(); i++)
+  for (typename Mat::size_type i=1; i<M.rows(); i++)
     {
       long double s = 0;
-      for (int j=1; j<=i; j++)
+      for (decltype(i) j=1; j<=i; j++)
         s -= ini[j]*inv[i-j];
       inv[i] = s * inv0;
     }
-  // for (int i=0; i<M.rows(); i++) cout << " " << long(inv[i]); cout<<endl;
+  // for (typename Mat::size_type i=0; i<M.rows(); i++) cout << " " << long(inv[i]); cout<<endl;
 
-  for (int i=1; i<=M.rows(); i++)
-    for (int j=1; j<=M.cols(); j++)
+  for (typename Mat::size_type i=1; i<=M.rows(); i++)
+    for (decltype(i) j=1; j<=M.cols(); j++)
       if (i > j)
         I(i,j) = M(i,j) = 0;
       else
@@ -53,8 +53,8 @@ InitMat(Mat& M, double ini[], Mat& I, double inv[], double& cond, double& maxe)
 
   maxe = 0;   // max. element
   double a = 0, b = 0, e;
-  for (int i=1; i<=M.rows(); i++)
-    for (int j=1; j<=M.cols(); j++)
+  for (typename Mat::size_type i=1; i<=M.rows(); i++)
+    for (decltype(i) j=1; j<=M.cols(); j++)
       {
         e = std::abs(M(i,j));
         if (e > maxe) maxe = e;
